@@ -3,8 +3,6 @@ from __future__ import annotations
 from importlib import import_module
 from logging import CRITICAL, INFO, Formatter, getLogger
 from logging.handlers import RotatingFileHandler
-from os import listdir
-from os.path import isfile
 from pathlib import Path
 from random import choice
 from sys import modules
@@ -14,7 +12,7 @@ from typing import TYPE_CHECKING
 from aiohttp import ClientSession
 from asyncpg import create_pool
 from nextcord import Embed, Interaction, Member, Thread, User, abc
-from nextcord.ext.commands import Bot, when_mentioned_or
+from nextcord.ext.commands import AutoShardedBot, when_mentioned, when_mentioned_or
 
 from .blacklist import Blacklist
 from .emojis import Emojis
@@ -31,7 +29,7 @@ if TYPE_CHECKING:
     from typing import Any, Callable, Optional, Union
 
     from asyncpg import Pool
-    from nextcord import Guild, Message
+    from nextcord import Guild, Message, PartialMessageable
 
 
 log = getLogger(__name__)
@@ -50,6 +48,30 @@ I have been up since {created_at} and I serve for you!
 """
 
 
+initialise = """
+CREATE TABLE IF NOT EXISTS guilds (
+    id BIGINT PRIMARY KEY,
+    prefix VARCHAR
+);
+CREATE TABLE commands (
+    command VARCHAR NOT NULL,
+    guild BIGINT,
+    channel BIGINT,
+    member BIGINT NOT NULL,
+    amount INT,
+    UNIQUE(command, guild, channel, member)
+);
+CREATE TABLE blacklist_guilds (
+    id BIGINT PRIMARY KEY,
+    reason VARCHAR
+);
+CREATE TABLE blacklist_users (
+    id BIGINT PRIMARY KEY,
+    reason VARCHAR
+);
+"""
+
+
 def get_handler():
     h = RotatingFileHandler(
         "./logs/bot/io.log",
@@ -67,7 +89,7 @@ def get_handler():
     return h
 
 
-class BotBase(Bot):
+class BotBase(AutoShardedBot):
     db: Pool
     session: ClientSession
     blacklist: Optional[Blacklist]
@@ -88,7 +110,18 @@ class BotBase(Bot):
             return config_module, ""
 
     def __init__(self, *args, config_module: str = "config", **kwargs) -> None:
-        pre = kwargs.pop("command_prefix", self.get_pre)
+        cfg, mod = self.get_config(config_module.rstrip(".py"))
+        config = import_module(cfg)
+
+        if not getattr(config, "prefix", None):
+            default_getter = when_mentioned
+            kwargs["help_command"] = None
+            set_help = False
+        else:
+            default_getter = self.get_pre
+            set_help = True
+
+        pre = kwargs.pop("command_prefix", default_getter)
         saf = kwargs.pop("strip_after_prefix", True)
         ca = kwargs.pop("case_insensitive", True)
 
@@ -112,9 +145,6 @@ class BotBase(Bot):
 
         self.loop.set_exception_handler(self.asyncio_handler)
 
-        cfg, mod = self.get_config(config_module.rstrip(".py"))
-        config = import_module(cfg)
-
         self.mod = mod
 
         self.db_enabled: bool
@@ -135,6 +165,7 @@ class BotBase(Bot):
             self.db_kwargs = {
                 "database": db_name,
                 "user": db_user,
+                "host": db_host,
             }
         else:
             self.db_enabled = False
@@ -157,6 +188,7 @@ class BotBase(Bot):
         self.emojiset: Any = getattr(config, "emojiset", Emojis())
         self.logchannel: int | None = getattr(config, "logchannel", None)
         self.guild_ids: list[int] | None = getattr(config, "guild_ids", None)
+        self.database_init: str = initialise + getattr(config, "database_init", "")
 
         self._single_events: dict[str, Callable] = {
             "on_message": self.get_wrapped_message,
@@ -170,10 +202,12 @@ class BotBase(Bot):
         }
 
         self.load_extension("jishaku")
-        self.load_extension("botbase.coggies.help")
+
+        if set_help:
+            self.load_extension("botbase.cogs.help")
 
         if self.blacklist_enabled:
-            self.load_extension("botbase.coggies.blacklist")
+            self.load_extension("botbase.cogs.blacklist")
             self.blacklist = None
 
     @property
@@ -317,7 +351,9 @@ class BotBase(Bot):
 
     def get_wrapped_channel(
         self,
-        channel: Union[abc.GuildChannel, abc.PrivateChannel, Thread],
+        channel: Union[
+            abc.GuildChannel, abc.PrivateChannel, Thread, PartialMessageable
+        ],
     ) -> Union[WrappedThread, WrappedChannel]:
         if isinstance(channel, Thread):
             return WrappedThread(channel, self)
@@ -400,6 +436,44 @@ class BotBase(Bot):
                     ctx.author.id,
                 )
 
+    async def on_application_command_completion(self, inter: MyInter):
+        if not self.db_enabled:
+            return
+
+        if inter.guild is not None:
+            await self.db.execute(
+                """INSERT INTO commands (command, guild, channel, member, amount) 
+                VALUES ($1,$2,$3,$4,$5) 
+                ON CONFLICT (command, guild, channel, member) DO UPDATE
+                    SET amount = commands.amount + 1""",
+                inter.command,
+                inter.guild.id,
+                inter.channel.id,  # type: ignore
+                inter.author.id,
+                1,
+            )
+        else:
+            a = await self.db.fetchval(
+                "SELECT * FROM commands WHERE member=$1 AND channel IS NULL and guild IS NULL",
+                inter.author.id,
+            )
+            if a is None:
+                await self.db.execute(
+                    """INSERT INTO commands (command, guild, channel, member, amount) 
+                    VALUES ($1,$2,$3,$4,$5)""",
+                    inter.command,
+                    None,
+                    None,
+                    inter.author.id,
+                    1,
+                )
+            else:
+                await self.db.execute(
+                    """UPDATE commands SET amount = commands.amount + 1 
+                    WHERE member=$1 AND channel IS NULL and guild IS NULL""",
+                    inter.author.id,
+                )
+
     async def on_guild_join(self, guild: Guild):
         if not self.logchannel:
             return
